@@ -1,7 +1,7 @@
 /*
  * This file is part of uudeview, the simple and friendly multi-part multi-
- * file uudecoder  program  (c)  1994 by Frank Pilhofer. The author may be
- * contacted by his email address,          fp@informatik.uni-frankfurt.de
+ * file uudecoder  program  (c) 1994-2001 by Frank Pilhofer. The author may
+ * be contacted at fp@fpx.de
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  * of UUDeview. It should not be included from other packages. Subject to
  * change without notice. Do not depend on anything here.
  *
- * $Id: uuint.h,v 1.15 1996/11/03 12:48:06 fp Exp $
+ * $Id: uuint.h,v 1.5 2002/04/06 01:53:30 root Exp $
  */
 
 /*
@@ -177,6 +177,7 @@ extern void *uu_MsgCBArg;
 extern void *uu_BusyCBArg;
 extern void *uu_FileCBArg;
 extern void *uu_FFCBArg;
+extern void *uu_FNCBArg;
 
 /*
  * variables
@@ -196,6 +197,9 @@ extern int uu_headercount;
 extern int uu_usepreamble;
 extern int uu_handletext;
 extern int uu_tinyb64;
+extern int uu_remove_input;
+extern int uu_more_mime;
+extern int uu_dotdot;
 
 extern char *uusavepath;
 extern char *uuencodeext;
@@ -252,10 +256,11 @@ extern char *uunconc_BHxlat, *uunconc_save;
 extern "C" {
 #endif
 
-extern void   (*uu_MsgCallback)  (void *, char *, int);
-extern int    (*uu_BusyCallback) (void *, uuprogress *);
-extern int    (*uu_FileCallback) (void *, char *, char *, int);
-extern char * (*uu_FNameFilter)  (void *, char *);
+extern void   (*uu_MsgCallback)     (void *, char *, int);
+extern int    (*uu_BusyCallback)    (void *, uuprogress *);
+extern int    (*uu_FileCallback)    (void *, char *, char *, int);
+extern char * (*uu_FNameFilter)     (void *, char *);
+extern char * (*uu_FileNameCallback)(void *, char *, char *);
 
 /*
  * Functions from uulib.c that aren't defined in <uudeview.h>
